@@ -1,5 +1,5 @@
 var _ogre_property_prerequisites_8h =
 [
     [ "_OgrePropertyExport", "_ogre_property_prerequisites_8h.html#af28d18a1b484acf19bec2841bc9ec96f", null ],
-    [ "PropertyAlloc", "_ogre_property_prerequisites_8h.html#abf77d3dd844d261fb692cafe35cc7a07", null ]
+    [ "Ogre::PropertyAlloc", "namespace_ogre.html#abf77d3dd844d261fb692cafe35cc7a07", null ]
 ];
\ No newline at end of file
