@@ -3,5 +3,5 @@ var dir_9cbf97e0cfb261f487ab96341cbaf2c6 =
     [ "OgreAndroidEGLContext.h", "_ogre_android_e_g_l_context_8h.html", "_ogre_android_e_g_l_context_8h" ],
     [ "OgreAndroidEGLSupport.h", "_ogre_android_e_g_l_support_8h.html", "_ogre_android_e_g_l_support_8h" ],
     [ "OgreAndroidEGLWindow.h", "_ogre_android_e_g_l_window_8h.html", "_ogre_android_e_g_l_window_8h" ],
-    [ "OgreGLES2Util.h", "_e_g_l_2_android_2_ogre_g_l_e_s2_util_8h.html", "_e_g_l_2_android_2_ogre_g_l_e_s2_util_8h" ]
+    [ "OgreGLES2Util.h", "_android_2_ogre_g_l_e_s2_util_8h.html", "_android_2_ogre_g_l_e_s2_util_8h" ]
 ];
\ No newline at end of file
